var indexSectionsWithContent =
{
  0: "\"_abcdefghijklmnopqrstuvwxyz",
  1: "_abcdefghijklmnopqrstuvwxz",
  2: "_abcdefghijklmnopqrstuvwxz",
  3: "_abcdefghiklmnopqrstuvwxz",
  4: "_abcdefghijklmnopqrstuvwxyz",
  5: "_abcdefghiklmnopqrstuvwxz",
  6: "_abcdefghilmopqrstuwxz",
  7: "abcdefghijklmnopqrstuvwxz",
  8: "_abcdefghilmnopqrstuvwz",
  9: "abcdefghijklmnopqrstuvwxz",
  10: "\"abcdefghijlmnopqrstuvxz"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

